@@ -80,7 +80,7 @@ class Vector(complex):
                 except TypeError:
                     # Create Vector from a single-argument using our
                     # implementation
-                    x, y = *_object_to_xy(x)
+                    x, y = _object_to_xy(x)
                     try:
                         return super().__new__(cls, x, y)
                     except TypeError:
